########################################################################
#                         bunch of (random)                            #
#                            functions                                 #
#                           for potShop                                #
#                     copyright 2009 Louis Taylor                      #
#     this program is free software; you can redistribute it and/or    #
#    modify it under the terms of the GNU Library General Public       #
#    License as published by the Free Software Foundation; either      #
#    version 3 of the License, or (at your option) any later version.  #
#                                                                      #
#    this program is distributed in the hope that it will be useful,   #
#    but WITHOUT ANY WARRANTY; without even the implied warranty of    #
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU #
#    Library General Public License for more details.                  #
#                                                                      #
#    You should have received a copy of the GNU Library General Public #
#    License along with this program; If not, write to the Free        #
#    Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,   #
#    MA  02110-1301 USA                                                #
########################################################################

import os, sys, Image
def gen_svg(template, potnumber, background_image, diameter):
    '''returns a string of the svg template + background
    image + pot number.
    this is raw text so it need to be saved after
    being returned'''
    if not os.path.exists(template):
        raise Exception, '''bad path to template image '%s' ''' % template
    elif not os.path.exists(background_image):
        print '''background image '%s' could no be opened''' % background_image
    
    potnumber = int(potnumber)
    
    file = open(template, 'r')
    xml = file.read()
                #replace $POTNUMBER with potnumber        #same but with $BACKGROUND                #etc
    outputxml = xml.replace('$POTNUMBER', str(potnumber) ).replace('$BACKGROUND', background_image).replace('$DIAMETER', str(diameter))
    return outputxml

def inkscape_is_installed():
    '''returns True if inkscape can be started from the shell
    else returnes False'''
    #try to load inkscape with no gui
    inkscapecommand = os.popen('inkscape -z')
    #rather crude way of checking if inkscape is installed only works on bash
    ##if inkscapecommand.read() == 'bash: inkscape: command not found':
    
    # bit better.
    if 'command not found' in inkscapecommand.read():
        return False
    else:
        return True

class potdatabase(object):
    def __init__(self):
        self.home = os.getenv('HOME')
        self.potdir = '.potshop'
        self.databasefilename = 'potNumberDatabase'
        self.configdir = os.path.join( self.home, self.potdir )
        self.potlistfpath = os.path.join( self.configdir, self.databasefilename )
        
        
        if not os.path.exists(self.potlistfpath):
            os.system('mkdir -p %s' % self.configdir )
            self.potlistfile_w = open(self.potlistfpath, 'w')
        
        self.potlistfile_r = open(self.potlistfpath, 'r')
        #self.potlistfile_w = open(self.potlistfpath, 'w')
        
        self.reload()
        
    def __add__(self, pot):
        self.add_pot(pot)
        
    def remove(self, pot_to_remove):
        try:
            self.potlist.remove(pot_to_remove)
        except:
            print 'this pot is not in the database'
            
    def add_pot(self, pot):
        self.potlist = self.potlist + [int(pot)]
        self.potlistfile_w = open(self.potlistfpath, 'w')
        #print self.potlist
        self.save()
        #self.reload()

    def save(self):
        '''saves the list database and saves it to disk'''
        self.potlist.sort()
        for pot in self.potlist:
            self.potlistfile_w.writelines( str(pot)+'\n' )
        
    def reload(self):
        '''loads the file database and changes it to a list'''
        self.potlist = [int(line) for line in self.potlistfile_r.readlines()]
        
    def pots(self):
        '''returns a list of all the pot numbers'''
        return self.potlist
    
def get_template_image(pot_template):
    return list(os.path.splitext(pot_template))[0] + '.png'

def pngtosvg_path(pngpath):
    return os.path.splitext(pngpath)[0] + '.pvg' #os.path.splitext(pngpath)[1]

def lastpot():
    '''returns integer of the last entered pot number
    gets it from '/last_pot' '''
    
    #TODO stuff
    
def make_thumb(image, path, resampling):
    
    '''make_thumb(image, file_to_save_to, resample)
    makes a thumbnail of image and
    saves it to path
    
    set resample to 0 for fast scaling set it to
    1 or higher for nicer looking images'''
    resampling = int(resampling)
    
    im = Image.open(image)
    im.thumbnail((350, 350), resample=resampling)
    im.save(path, "PNG")
    
def new_thumb_name(image, saveto):
    '''returns a generated str path to 
    a thumbnail path.
    saveto = the dir to save the thumbs to - probably $HOME/.potshop/thumbs
    e.g. new_thumb_name('/templates/pot1.png', $HOME/.potshop/thumbs)
    returns:
    '$HOME/.potshop/thumbs/pot1.png.thumb' '''
    
    import os
    filename = os.path.split(image)[1]
    splitpath = os.path.split(filename)
    
    return os.path.join(saveto, filename+'.thumb' )
    
